<?php # $Id: lang_bg.inc.php 2061 2007-12-06 11:12:30Z garvinhicking $

/**
 *  @version $Revision: 2061 $
 *  @author Ivan Cenov jwalker@hotmail.bg
 *  EN-Revision: 2034
*/

    @define('PLUGIN_EVENT_TEXTILE_NAME', '  : Textile');
    @define('PLUGIN_EVENT_TEXTILE_DESC', '    Textile .');
    @define('PLUGIN_EVENT_TEXTILE_TRANSFORM', ' <a href="http://www.textism.com/tools/textile/">Textile</a>  ');
    @define('PLUGIN_EVENT_TEXTILE_VERSION', '  Textile');
    @define('PLUGIN_EVENT_TEXTILE_VERSION_DESCRIPTION', '   Textile   ?');
